ISO-8859-8

במקביל לישיבת הקבינט שדנה בהחלטת מועצת הביטחון לקרוא להפסקת אש מיידית, מסמן רה"מ את עמדתו: "אף גורם חיצוני לא יקבע את זכותנו להגן על אזרחינו. צה"ל ימשיך בביצוע המשימות שהוטלו עליו". אולמרט הוסיף ואמר כי הירי הבוקר מעזה "מוכיח שהחלטת האו"ם לא תקוים ע"י ארגוני הטרור" במקביל לישיבת הקבינט המדיני-ביטחוני שמתקיימת על רקע החלטת מועצת הביטחון של האו"ם הלילה שקראה לישראל להפסיק את הלחימה ברצועת עזה - אמר בצהריים (ו') ראש הממשלה, אהוד אולמרט, כי "מאז ומעולם מדינת ישראל לא הסכימה ששום גורם חיצוני יקבע את זכותה ...